const webpack = require('webpack')
const ExtractTextPlugin = require('extract-text-webpack-plugin')
const HtmlWebpackPlugin = require('html-webpack-plugin')
const DashboardPlugin = require('webpack-dashboard/plugin');
const autoprefixer = require('autoprefixer')
const csswring = require('csswring')
const FaviconsWebpackPlugin = require('favicons-webpack-plugin')
const fs = require('fs')
const pgk = JSON.parse(fs.readFileSync(__dirname + '/package.json'))


const ENV = process.env.APP_ENV || 'local'
let defines = {}

const build = {
    ENV: ENV,
    VERSION: pgk.version,
    BUILD: pgk.build
}
console.log('ENV', ENV, process.env.APP_ENV)
if (ENV === 'local') {
    console.log('setting env to develop...')
    defines['process.env.NODE_ENV'] = JSON.stringify('development')
} else {
    console.log('setting env to production...')
    defines['process.env.NODE_ENV'] = JSON.stringify('production')
}

defines['__MOJITO_BUILD__'] = JSON.stringify(build)

let output = {
    path: 'public/',
    filename: '[name].js', // Template based on keys in entry above
    chunkFilename: '[id].js'
}

const html = {
    title: 'Mojito',
    filename: 'index.html',
    template: './src/html/index.html',
    // inject: 'body',
    hash: true,
    MOJITO_CONFIG: JSON.stringify({
        BASE_URL: 'http://localhost:8081/'
    })
}

let plugins = []


let lessLoader = 'style-loader!css-loader?sourceMap!postcss-loader!less-loader?sourceMap'
let cssLoader = 'style-loader!css-loader?modules!postcss-loader'

if (ENV === 'dev' || ENV === 'prod') {
    lessLoader = ExtractTextPlugin.extract('style-loader', 'css-loader?sourceMap!postcss-loader!less-loader?sourceMap', {publicPath: './'})
    cssLoader = ExtractTextPlugin.extract('style-loader', 'css-loader?modules!postcss-loader', {publicPath: './'})
    plugins.push(new ExtractTextPlugin('[name].css', {allChunks: true, publicPath: './'}))
    output = {
        publicPath: '[hash]/',
        path: 'public/' + ENV + '/[hash]/',
        filename: '[name].js', // Template based on keys in entry above
        chunkFilename: '[id].js'
    }
    html.filename = '../index.html'
    plugins.push(new webpack.ExtendedAPIPlugin())
    plugins.push(new webpack.optimize.DedupePlugin())
}
if (ENV === 'prod') {
    html.CS_CONFIG = JSON.stringify({
        BASE_URL: 'https://mojitoapi.agentur-mint.at'
    })

}else{
    console.log('add dashboard')
    plugins.push(new DashboardPlugin())
}

plugins = plugins.concat([
    new webpack.BannerPlugin('Mojito'),
    new HtmlWebpackPlugin(html),
    new webpack.DefinePlugin(defines),
    new webpack.ContextReplacementPlugin(/moment[\/\\]locale$/, /de|en/),
    new FaviconsWebpackPlugin({
        logo: './src/images/favicon.png',
        publicPath: './'
    })
])



module.exports = {
    entry: {
        app: ['./src/js/app.jsx'],
    },
    module: {
        loaders: [
            {test: /\.js$/, exclude: /node_modules/, loaders: ['babel']},
            {test: /\.jsx$/, exclude: /node_modules/, loaders: ['babel']},
            {test: /\.css$/, loader: cssLoader},
            {test: /\.less$/, loader: lessLoader},
            {test: /\.woff(\?v=[0-9]\.[0-9]\.[0-9])?$/, loader: 'url-loader?limit=100000&minetype=application/font-woff'},
            {test: /\.woff2(\?v=[0-9]\.[0-9]\.[0-9])?$/, loader: 'url-loader?limit=100000&minetype=application/font-woff2'},
            {test: /\.(ttf|eot|svg)(\?v=[0-9]\.[0-9]\.[0-9])?$/, loader: 'file-loader' },
            {test: /\.json$/, loader: 'json-loader'},
            {test: /\.gif$/, loader: 'file-loader'},
            {test: /\.png$/, loader: 'file-loader'},
            {test: /\.svg$/, loader: 'raw-loader'},
            { test: /\.ico$/, loader: 'file-loader', query: { mimetype: 'image/x-icon' }}
        ]
    },
    output: output,
    postcss: [autoprefixer, csswring],
    resolve: {
        alias: {},
        modulesDirectories: ['web_modules', 'node_modules', 'bower_components', 'src/js'],
        extensions: ['', '.js', '.jsx']
    },
    plugins: plugins
}
